
def zip_longest(*args, fillvalue=None):
    """
    Returns an iterator that aggregates elements from each of the iterables.
    The iterator stops when the shortest iterable is exhausted, filling in missing values with fillvalue.
    """
    iters = [iter(iterable) for iterable in args]
    while True:
        result = []
        for it in iters:
            try:
                result.append(next(it))
            except StopIteration:
                result.append(fillvalue)
        yield result


